@@ -302,6 +302,21 @@ def write_commands(commands, options, config, tempdir):
 def upload_stolen_from_dput_main(
         host, upload_methods, config, debug, simulate,
         files_to_upload, ftp_passive_mode):
+    """ Upload files to the host.
+
+        :param host: Configuration host name.
+        :param upload_methods: Mapping of {method_name: callable}.
+        :param config: `ConfigParser` instance for this application.
+        :param debug: If true, enable debugging output.
+        :param simulate: If true, simulate the upload only.
+        :param files_to_upload: Collection of file names to upload.
+        :param ftp_passive_mode: If true, enable FTP passive mode.
+        :return: ``None``.
+
+        Upload the specified files to the host, using the method and
+        credentials from the configuration for the host.
+
+        """
     # Messy, yes. But it isn't referenced by the upload method anyway.
     if config.get(host, 'method') == 'local':
         fqdn = 'localhost'
@@ -520,7 +535,7 @@ if __name__ == "__main__":
         sys.exit(1)
 
 
-# Copyright © 2015–2017 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2018 Ben Finney <bignose@debian.org>
 # Copyright © 2008–2013 Y Giridhar Appaji Nag <appaji@debian.org>
 # Copyright © 2004–2009 Thomas Viehmann <tv@beamnet.de>
 # Copyright © 2000–2004 Christian Kurz <shorty@debian.org>
@@ -536,7 +551,7 @@ if __name__ == "__main__":
 # See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 
 
 # Local variables:
