@@ -7,8 +7,8 @@
 
 """ Helper functionality for Dput test suite. """
 
-import builtins
 import base64
+import builtins
 import collections
 import collections.abc
 import errno
@@ -29,8 +29,6 @@ import unittest.mock
 import weakref
 
 
-__metaclass__ = type
-
 try:
     # Python 2 types.
     basestring
@@ -463,19 +461,19 @@ except NameError:
         def __init__(self, *args, **kwargs):
             (args, kwargs) = _ensure_ioerror_args(
                     args, kwargs, errno_value=errno.ENOENT)
-            super(FileNotFoundError, self).__init__(*args, **kwargs)
+            super().__init__(*args, **kwargs)
 
     class FileExistsError(IOError):
         def __init__(self, *args, **kwargs):
             (args, kwargs) = _ensure_ioerror_args(
                     args, kwargs, errno_value=errno.EEXIST)
-            super(FileExistsError, self).__init__(*args, **kwargs)
+            super().__init__(*args, **kwargs)
 
     class PermissionError(IOError):
         def __init__(self, *args, **kwargs):
             (args, kwargs) = _ensure_ioerror_args(
                     args, kwargs, errno_value=errno.EPERM)
-            super(PermissionError, self).__init__(*args, **kwargs)
+            super().__init__(*args, **kwargs)
 
 
 def make_fake_file_scenarios(path=None):
@@ -835,7 +833,7 @@ class TestDoubleWithRegistry:
     function_scenario_params_by_class = NotImplemented
 
     def __new__(cls, *args, **kwargs):
-        superclass = super(TestDoubleWithRegistry, cls)
+        superclass = super()
         if superclass.__new__ is object.__new__:
             # The ‘object’ implementation complains about extra arguments.
             instance = superclass.__new__(cls)
@@ -846,7 +844,7 @@ class TestDoubleWithRegistry:
         return instance
 
     def __init__(self, *args, **kwargs):
-        super(TestDoubleWithRegistry, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._set_method_per_scenario()
 
     def _make_set_scenario_method(self, scenario_class, params):
@@ -967,7 +965,7 @@ class FileDouble(TestDoubleWithRegistry):
 
         self._set_stat_result()
 
-        super(FileDouble, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def _set_stat_result(self):
         """ Set the `os.stat` result for this file. """
@@ -1403,7 +1401,7 @@ class SubprocessDouble(TestDoubleWithRegistry):
             stream_double_name = '{name}_double'.format(name=stream_name)
             setattr(self, stream_double_name, file_double)
 
-        super(SubprocessDouble, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def set_popen_double(self):
         """ Set the `PopenDouble` for this instance. """
@@ -1689,7 +1687,7 @@ def patch_os_spawnv(testcase):
     testcase.addCleanup(func_patcher.stop)
 
 
-# Copyright © 2015–2017 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2018 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
