@@ -40,8 +40,6 @@ from .test_configfile import (
         set_config,
         )
 
-__metaclass__ = type
-
 
 class _FieldsMapping:
     """ A mapping to stand in for the `dict` of an `email.message.Message`. """
@@ -51,7 +49,7 @@ class _FieldsMapping:
             self._message = kwargs.pop('_message')
         except KeyError:
             raise TypeError("no ‘_message’ specified for this mapping")
-        super(_FieldsMapping, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def __len__(self, *args, **kwargs):
         return self._message.__len__(*args, **kwargs)
@@ -85,7 +83,7 @@ class FakeMessage(email.message.Message, object):
     """ A fake RFC 2822 message that mocks the obsolete `rfc822.Message`. """
 
     def __init__(self, *args, **kwargs):
-        super(FakeMessage, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.dict = _FieldsMapping(_message=self)
 
 
@@ -309,7 +307,7 @@ class parse_changes_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(parse_changes_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.test_infile = io.StringIO()
@@ -381,7 +379,7 @@ class check_upload_variant_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(check_upload_variant_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.set_changes_document(self.fields)
@@ -539,7 +537,7 @@ class source_check_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(source_check_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.test_args = {
@@ -656,7 +654,7 @@ class verify_files_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(verify_files_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.file_double_by_path = {}
@@ -1156,7 +1154,7 @@ class guess_upload_host_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(guess_upload_host_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         set_config(
@@ -1224,7 +1222,7 @@ class guess_upload_host_TestCase(
         self.assertIn(expected_output, sys.stdout.getvalue())
 
 
-# Copyright © 2015–2017 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2018 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
