@@ -23,7 +23,8 @@ import dput.dput
 from dput.helper import dputhelper
 
 from .helper import (
-        EXIT_STATUS_FAILURE, EXIT_STATUS_SUCCESS,
+        EXIT_STATUS_FAILURE,
+        EXIT_STATUS_SUCCESS,
         FakeSystemExit,
         PasswdEntry,
         patch_os_environ,
@@ -117,7 +118,7 @@ class main_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(main_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         set_config(
@@ -1065,7 +1066,7 @@ class main_UploadMethodTestCase(
                     "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
                     unittest.mock.ANY, unittest.mock.ANY,
                     False),
-                'expected_kwargs': {'progress': 23, 'port': "42"},
+                'expected_kwargs': {'progress': 23, 'port': 42},
                 'expected_stdout_output': "D: Using active ftp",
                 }),
             ('method-ftp config-passive-mode', {
@@ -1232,7 +1233,7 @@ class main_DinstallTestCase(
         dput.dput.dinstall_caller.assert_called_with(*expected_args)
 
 
-# Copyright © 2015–2017 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2018 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
