@@ -27,7 +27,8 @@ from dput.helper import dputhelper
 
 from .helper import (
         EXIT_STATUS_COMMAND_NOT_FOUND,
-        EXIT_STATUS_FAILURE, EXIT_STATUS_SUCCESS,
+        EXIT_STATUS_FAILURE,
+        EXIT_STATUS_SUCCESS,
         SubprocessDouble,
         patch_subprocess_check_call,
         patch_sys_argv,
@@ -74,7 +75,7 @@ class check_call_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(check_call_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         patch_subprocess_check_call(self)
@@ -111,127 +112,6 @@ class check_call_TestCase(
                 testtools.matchers.DocTestMatches(
                     self.expected_output, flags=doctest.ELLIPSIS))
 
-
-class TimestampFile_TestCase(testtools.TestCase):
-    """ Base for test cases for the `TimestampFile` class. """
-
-    scenarios = NotImplemented
-
-    def setUp(self):
-        """ Set up test fixtures. """
-        super(TimestampFile_TestCase, self).setUp()
-
-        patch_time_time(self, itertools.count(1))
-
-        self.test_file = io.StringIO()
-        self.instance = dputhelper.TimestampFile(self.test_file)
-
-
-class TimestampFile_InstanceTestCase(
-        testscenarios.WithScenarios,
-        TimestampFile_TestCase):
-    """ Test cases for `TimestampFile` instance creation. """
-
-    scenarios = [
-            ('default', {}),
-            ]
-
-    def test_has_specified_file(self):
-        """ Should have specified file object as `f` attribute. """
-        self.assertIs(self.test_file, self.instance.f)
-
-    def test_has_attributes_from_component_file(self):
-        """ Should have attributes directly from component file. """
-        attr_names = [
-                'b0gUs',
-                'mode', 'name', 'encoding',
-                'readable', 'seekable', 'writable',
-                'read', 'seek', 'tell',
-                ]
-        for attr_name in attr_names:
-            expected_attr_value = getattr(self.test_file, attr_name, None)
-            self.expectThat(
-                    getattr(self.instance, attr_name, None),
-                    testtools.matchers.Equals(expected_attr_value))
-
-
-class TimestampFile_write_TestCase(
-        testscenarios.WithScenarios,
-        TimestampFile_TestCase):
-    """ Test cases for `TimestampFile.write` method. """
-
-    scenarios = [
-            ('empty', {
-                'test_output': "",
-                'expected_lines': [],
-                }),
-            ('lines-one', {
-                'test_output': textwrap.dedent("""\
-                    Lorem ipsum, dolor sit amet.
-                    """),
-                'expected_lines': [
-                    "1: Lorem ipsum, dolor sit amet.",
-                    "",
-                    ],
-                }),
-            ('lines-three', {
-                'test_output': textwrap.dedent("""\
-                    Lorem ipsum, dolor sit amet,
-                    consectetur adipiscing elit.
-                    Integer non pulvinar risus, sed malesuada diam.
-                    """),
-                'expected_lines': [
-                    "1: Lorem ipsum, dolor sit amet,",
-                    "2: consectetur adipiscing elit.",
-                    "3: Integer non pulvinar risus, sed malesuada diam.",
-                    "",
-                    ],
-                }),
-            ('lines-two-with-trail', {
-                'test_output': textwrap.dedent("""\
-                    Lorem ipsum, dolor sit amet,
-                    consectetur adipiscing elit.
-                    Integer non pulvinar risus"""),
-                'expected_lines': [
-                    "1: Lorem ipsum, dolor sit amet,",
-                    "2: consectetur adipiscing elit.",
-                    "3: Integer non pulvinar risus",
-                    ],
-                }),
-            ]
-
-    def test_has_expected_content_for_output(self):
-        """ Should have expected content for specified `write` output. """
-        self.instance.write(self.test_output)
-        expected_lines = self.expected_lines
-        if self.expected_lines:
-            if self.expected_lines[-1]:
-                # Expecting an unterminated final line.
-                expected_lines = self.expected_lines[:-1]
-                expected_lines.append("")
-            else:
-                # Expecting no output following newline.
-                expected_lines = self.expected_lines
-        expected_content = "\n".join(expected_lines)
-        self.assertEqual(expected_content, self.instance.f.getvalue())
-
-
-class TimestampFile_close_TestCase(
-        testscenarios.WithScenarios,
-        TimestampFile_TestCase):
-    """ Test cases for `TimestampFile.write` method. """
-
-    scenarios = TimestampFile_write_TestCase.scenarios
-
-    @testtools.skip("TimestampFile.close method is broken")
-    def test_has_expected_final_line(self):
-        """ Should have expected final line. """
-        self.instance.write(self.test_output)
-        self.instance.f.seek(0)
-        self.instance.close()
-        expected_content = self.expected_lines[-1]
-        self.assertEqual(expected_content, self.instance.f.getvalue())
-
 
 class FileWithProgress_TestCase(
         testscenarios.WithScenarios,
@@ -247,7 +127,7 @@ class FileWithProgress_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(FileWithProgress_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.test_file = io.StringIO(
@@ -376,7 +256,7 @@ class FileWithProgress_OutputTestCase(FileWithProgress_TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(FileWithProgress_OutputTestCase, self).setUp()
+        super().setUp()
 
         self.test_file = io.StringIO(self.content)
         self.test_progressf = io.StringIO()
@@ -498,7 +378,7 @@ class make_text_stream_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(make_text_stream_TestCase, self).setUp()
+        super().setUp()
 
         self.patch_locale_getpreferredencoding()
 
@@ -836,7 +716,7 @@ class get_progname_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(get_progname_TestCase, self).setUp()
+        super().setUp()
 
         self.test_argv = [self.argv_zero] + self.argv_remain
 
@@ -879,7 +759,7 @@ class get_distribution_version_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(get_distribution_version_TestCase, self).setUp()
+        super().setUp()
 
         patch_pkg_resources_get_distribution(self)
 
@@ -890,7 +770,7 @@ class get_distribution_version_TestCase(
         self.assertEqual(expected_version, result)
 
 
-# Copyright © 2015–2017 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2018 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
